@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,10 +27,14 @@
 
 
 
+
+from .fetchers import NUMetadatasFetcher
+
+
 from .fetchers import NUBFDSessionsFetcher
 
 
-from .fetchers import NUUnderlaysFetcher
+from .fetchers import NUGlobalMetadatasFetcher
 
 
 from .fetchers import NUCustomPropertiesFetcher
@@ -42,7 +46,7 @@ class NUUplinkConnection(NURESTObject):
     """ Represents a UplinkConnection in the VSD
 
         Notes:
-            None
+            Configuration of VNS Gateway uplinks
     """
 
     __rest_name__ = "uplinkconnection"
@@ -51,41 +55,47 @@ class NUUplinkConnection(NURESTObject):
     
     ## Constants
     
-    CONST_INTERFACE_CONNECTION_TYPE_AUTOMATIC = "AUTOMATIC"
+    CONST_INTERFACE_CONNECTION_TYPE_USB_MODEM = "USB_MODEM"
+    
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    
+    CONST_MODE_ANY = "Any"
+    
+    CONST_ADVERTISEMENT_CRITERIA_CONTROL_SESSION = "CONTROL_SESSION"
     
     CONST_ADVERTISEMENT_CRITERIA_BFD = "BFD"
     
     CONST_ROLE_UNKNOWN = "UNKNOWN"
     
-    CONST_INTERFACE_CONNECTION_TYPE_PCI_EXPRESS = "PCI_EXPRESS"
-    
-    CONST_ROLE_NONE = "NONE"
-    
-    CONST_ROLE_SECONDARY = "SECONDARY"
-    
-    CONST_INTERFACE_CONNECTION_TYPE_EMBEDDED = "EMBEDDED"
-    
-    CONST_ADVERTISEMENT_CRITERIA_OPERATIONAL_LINK = "OPERATIONAL_LINK"
-    
-    CONST_INTERFACE_CONNECTION_TYPE_USB_MODEM = "USB_MODEM"
-    
-    CONST_MODE_PPPOE = "PPPoE"
-    
     CONST_MODE_DYNAMIC = "Dynamic"
     
     CONST_MODE_LTE = "LTE"
     
-    CONST_ROLE_TERTIARY = "TERTIARY"
+    CONST_ADDRESS_FAMILY_IPV6 = "IPV6"
     
-    CONST_ADVERTISEMENT_CRITERIA_CONTROL_SESSION = "CONTROL_SESSION"
+    CONST_ADDRESS_FAMILY_IPV4 = "IPV4"
     
-    CONST_MODE_STATIC = "Static"
+    CONST_ADVERTISEMENT_CRITERIA_OPERATIONAL_LINK = "OPERATIONAL_LINK"
     
-    CONST_ADDRESS_IPV4 = "IPv4"
+    CONST_ROLE_SECONDARY = "SECONDARY"
+    
+    CONST_MODE_PPPOE = "PPPoE"
     
     CONST_INTERFACE_CONNECTION_TYPE_USB_ETHERNET = "USB_ETHERNET"
     
-    CONST_ADDRESS_IPV6 = "IPv6"
+    CONST_INTERFACE_CONNECTION_TYPE_AUTOMATIC = "AUTOMATIC"
+    
+    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
+    
+    CONST_ROLE_NONE = "NONE"
+    
+    CONST_INTERFACE_CONNECTION_TYPE_EMBEDDED = "EMBEDDED"
+    
+    CONST_ROLE_TERTIARY = "TERTIARY"
+    
+    CONST_MODE_STATIC = "Static"
+    
+    CONST_INTERFACE_CONNECTION_TYPE_PCI_EXPRESS = "PCI_EXPRESS"
     
     CONST_ROLE_PRIMARY = "PRIMARY"
     
@@ -108,15 +118,26 @@ class NUUplinkConnection(NURESTObject):
 
         # Read/Write Attributes
         
+        self._pat_enabled = None
         self._dns_address = None
+        self._dns_address_v6 = None
         self._password = None
+        self._last_updated_by = None
         self._gateway = None
+        self._gateway_v6 = None
         self._address = None
+        self._address_family = None
+        self._address_v6 = None
         self._advertisement_criteria = None
         self._secondary_address = None
         self._netmask = None
-        self._vlan_id = None
+        self._vlan = None
+        self._underlay_enabled = None
+        self._underlay_id = None
+        self._inherited = None
+        self._installer_managed = None
         self._interface_connection_type = None
+        self._entity_scope = None
         self._mode = None
         self._role = None
         self._role_order = None
@@ -128,36 +149,52 @@ class NUUplinkConnection(NURESTObject):
         self._associated_bgp_neighbor_id = None
         self._associated_underlay_name = None
         self._auxiliary_link = None
+        self._external_id = None
         
+        self.expose_attribute(local_name="pat_enabled", remote_name="PATEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dns_address", remote_name="DNSAddress", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="dns_address_v6", remote_name="DNSAddressV6", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="password", remote_name="password", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPv4', u'IPv6'])
+        self.expose_attribute(local_name="gateway_v6", remote_name="gatewayV6", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="address_family", remote_name="addressFamily", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPV4', u'IPV6'])
+        self.expose_attribute(local_name="address_v6", remote_name="addressV6", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="advertisement_criteria", remote_name="advertisementCriteria", attribute_type=str, is_required=False, is_unique=False, choices=[u'BFD', u'CONTROL_SESSION', u'OPERATIONAL_LINK'])
         self.expose_attribute(local_name="secondary_address", remote_name="secondaryAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="netmask", remote_name="netmask", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="vlan_id", remote_name="vlanId", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="vlan", remote_name="vlan", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="underlay_enabled", remote_name="underlayEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="underlay_id", remote_name="underlayID", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="inherited", remote_name="inherited", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="installer_managed", remote_name="installerManaged", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="interface_connection_type", remote_name="interfaceConnectionType", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUTOMATIC', u'EMBEDDED', u'PCI_EXPRESS', u'USB_ETHERNET', u'USB_MODEM'])
-        self.expose_attribute(local_name="mode", remote_name="mode", attribute_type=str, is_required=False, is_unique=False, choices=[u'Dynamic', u'LTE', u'PPPoE', u'Static'])
+        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="mode", remote_name="mode", attribute_type=str, is_required=False, is_unique=False, choices=[u'Any', u'Dynamic', u'LTE', u'PPPoE', u'Static'])
         self.expose_attribute(local_name="role", remote_name="role", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PRIMARY', u'SECONDARY', u'TERTIARY', u'UNKNOWN'])
-        self.expose_attribute(local_name="role_order", remote_name="roleOrder", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="role_order", remote_name="roleOrder", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="port_name", remote_name="portName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="download_rate_limit", remote_name="downloadRateLimit", attribute_type=float, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="uplink_id", remote_name="uplinkID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="uplink_id", remote_name="uplinkID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="username", remote_name="username", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="assoc_underlay_id", remote_name="assocUnderlayID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_bgp_neighbor_id", remote_name="associatedBGPNeighborID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_underlay_name", remote_name="associatedUnderlayName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="auxiliary_link", remote_name="auxiliaryLink", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
         # Fetchers
         
         
+        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.bfd_sessions = NUBFDSessionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.underlays = NUUnderlaysFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.custom_properties = NUCustomPropertiesFetcher.fetcher_with_object(parent_object=self, relationship="child")
@@ -167,12 +204,39 @@ class NUUplinkConnection(NURESTObject):
 
     # Properties
     
+    @property
+    def pat_enabled(self):
+        """ Get pat_enabled value.
+
+            Notes:
+                Indicates whether PAT is enabled on the underlay for this uplink connection.
+
+                
+                This attribute is named `PATEnabled` in VSD API.
+                
+        """
+        return self._pat_enabled
+
+    @pat_enabled.setter
+    def pat_enabled(self, value):
+        """ Set pat_enabled value.
+
+            Notes:
+                Indicates whether PAT is enabled on the underlay for this uplink connection.
+
+                
+                This attribute is named `PATEnabled` in VSD API.
+                
+        """
+        self._pat_enabled = value
+
+    
     @property
     def dns_address(self):
         """ Get dns_address value.
 
             Notes:
-                DNS server address
+                DNS server address.
 
                 
                 This attribute is named `DNSAddress` in VSD API.
@@ -185,7 +249,7 @@ class NUUplinkConnection(NURESTObject):
         """ Set dns_address value.
 
             Notes:
-                DNS server address
+                DNS server address.
 
                 
                 This attribute is named `DNSAddress` in VSD API.
@@ -194,6 +258,33 @@ class NUUplinkConnection(NURESTObject):
         self._dns_address = value
 
     
+    @property
+    def dns_address_v6(self):
+        """ Get dns_address_v6 value.
+
+            Notes:
+                IPv6 DNS server address.
+
+                
+                This attribute is named `DNSAddressV6` in VSD API.
+                
+        """
+        return self._dns_address_v6
+
+    @dns_address_v6.setter
+    def dns_address_v6(self, value):
+        """ Set dns_address_v6 value.
+
+            Notes:
+                IPv6 DNS server address.
+
+                
+                This attribute is named `DNSAddressV6` in VSD API.
+                
+        """
+        self._dns_address_v6 = value
+
+    
     @property
     def password(self):
         """ Get password value.
@@ -217,6 +308,33 @@ class NUUplinkConnection(NURESTObject):
         self._password = value
 
     
+    @property
+    def last_updated_by(self):
+        """ Get last_updated_by value.
+
+            Notes:
+                ID of the user who last updated the object.
+
+                
+                This attribute is named `lastUpdatedBy` in VSD API.
+                
+        """
+        return self._last_updated_by
+
+    @last_updated_by.setter
+    def last_updated_by(self, value):
+        """ Set last_updated_by value.
+
+            Notes:
+                ID of the user who last updated the object.
+
+                
+                This attribute is named `lastUpdatedBy` in VSD API.
+                
+        """
+        self._last_updated_by = value
+
+    
     @property
     def gateway(self):
         """ Get gateway value.
@@ -240,6 +358,33 @@ class NUUplinkConnection(NURESTObject):
         self._gateway = value
 
     
+    @property
+    def gateway_v6(self):
+        """ Get gateway_v6 value.
+
+            Notes:
+                IPv6 address of the gateway bound to the port.
+
+                
+                This attribute is named `gatewayV6` in VSD API.
+                
+        """
+        return self._gateway_v6
+
+    @gateway_v6.setter
+    def gateway_v6(self, value):
+        """ Set gateway_v6 value.
+
+            Notes:
+                IPv6 address of the gateway bound to the port.
+
+                
+                This attribute is named `gatewayV6` in VSD API.
+                
+        """
+        self._gateway_v6 = value
+
+    
     @property
     def address(self):
         """ Get address value.
@@ -263,6 +408,60 @@ class NUUplinkConnection(NURESTObject):
         self._address = value
 
     
+    @property
+    def address_family(self):
+        """ Get address_family value.
+
+            Notes:
+                IP address family of this UplinkConnection
+
+                
+                This attribute is named `addressFamily` in VSD API.
+                
+        """
+        return self._address_family
+
+    @address_family.setter
+    def address_family(self, value):
+        """ Set address_family value.
+
+            Notes:
+                IP address family of this UplinkConnection
+
+                
+                This attribute is named `addressFamily` in VSD API.
+                
+        """
+        self._address_family = value
+
+    
+    @property
+    def address_v6(self):
+        """ Get address_v6 value.
+
+            Notes:
+                IPv6 address for static configuration
+
+                
+                This attribute is named `addressV6` in VSD API.
+                
+        """
+        return self._address_v6
+
+    @address_v6.setter
+    def address_v6(self, value):
+        """ Set address_v6 value.
+
+            Notes:
+                IPv6 address for static configuration
+
+                
+                This attribute is named `addressV6` in VSD API.
+                
+        """
+        self._address_v6 = value
+
+    
     @property
     def advertisement_criteria(self):
         """ Get advertisement_criteria value.
@@ -322,7 +521,7 @@ class NUUplinkConnection(NURESTObject):
         """ Get netmask value.
 
             Notes:
-                Subnet mask
+                Subnet mask of the uplink connection if mode is set to Static.
 
                 
         """
@@ -333,7 +532,7 @@ class NUUplinkConnection(NURESTObject):
         """ Set netmask value.
 
             Notes:
-                Subnet mask
+                Subnet mask of the uplink connection if mode is set to Static.
 
                 
         """
@@ -341,30 +540,130 @@ class NUUplinkConnection(NURESTObject):
 
     
     @property
-    def vlan_id(self):
-        """ Get vlan_id value.
+    def vlan(self):
+        """ Get vlan value.
 
             Notes:
-                The tag of the uplink's parent VLAN
+                VLAN Id of this uplink
 
                 
-                This attribute is named `vlanId` in VSD API.
-                
         """
-        return self._vlan_id
+        return self._vlan
 
-    @vlan_id.setter
-    def vlan_id(self, value):
-        """ Set vlan_id value.
+    @vlan.setter
+    def vlan(self, value):
+        """ Set vlan value.
 
             Notes:
-                The tag of the uplink's parent VLAN
+                VLAN Id of this uplink
 
                 
-                This attribute is named `vlanId` in VSD API.
+        """
+        self._vlan = value
+
+    
+    @property
+    def underlay_enabled(self):
+        """ Get underlay_enabled value.
+
+            Notes:
+                Indicated whether route to underlay is enabled on this uplink connection.
+
+                
+                This attribute is named `underlayEnabled` in VSD API.
                 
         """
-        self._vlan_id = value
+        return self._underlay_enabled
+
+    @underlay_enabled.setter
+    def underlay_enabled(self, value):
+        """ Set underlay_enabled value.
+
+            Notes:
+                Indicated whether route to underlay is enabled on this uplink connection.
+
+                
+                This attribute is named `underlayEnabled` in VSD API.
+                
+        """
+        self._underlay_enabled = value
+
+    
+    @property
+    def underlay_id(self):
+        """ Get underlay_id value.
+
+            Notes:
+                Underlay Identifier of underlay associated with this uplink.
+
+                
+                This attribute is named `underlayID` in VSD API.
+                
+        """
+        return self._underlay_id
+
+    @underlay_id.setter
+    def underlay_id(self, value):
+        """ Set underlay_id value.
+
+            Notes:
+                Underlay Identifier of underlay associated with this uplink.
+
+                
+                This attribute is named `underlayID` in VSD API.
+                
+        """
+        self._underlay_id = value
+
+    
+    @property
+    def inherited(self):
+        """ Get inherited value.
+
+            Notes:
+                This flag will determine if the abstract connection is inherited from the instance template
+
+                
+        """
+        return self._inherited
+
+    @inherited.setter
+    def inherited(self, value):
+        """ Set inherited value.
+
+            Notes:
+                This flag will determine if the abstract connection is inherited from the instance template
+
+                
+        """
+        self._inherited = value
+
+    
+    @property
+    def installer_managed(self):
+        """ Get installer_managed value.
+
+            Notes:
+                Boolean flag to indicate that connection parameters will be configured by the installer onsite. Limited to ConnectionMode: PPPoE
+
+                
+                This attribute is named `installerManaged` in VSD API.
+                
+        """
+        return self._installer_managed
+
+    @installer_managed.setter
+    def installer_managed(self, value):
+        """ Set installer_managed value.
+
+            Notes:
+                Boolean flag to indicate that connection parameters will be configured by the installer onsite. Limited to ConnectionMode: PPPoE
+
+                
+                This attribute is named `installerManaged` in VSD API.
+                
+        """
+        self._installer_managed = value
 
     
     @property
@@ -394,6 +693,33 @@ class NUUplinkConnection(NURESTObject):
         self._interface_connection_type = value
 
     
+    @property
+    def entity_scope(self):
+        """ Get entity_scope value.
+
+            Notes:
+                Specify if scope of entity is Data center or Enterprise level
+
+                
+                This attribute is named `entityScope` in VSD API.
+                
+        """
+        return self._entity_scope
+
+    @entity_scope.setter
+    def entity_scope(self, value):
+        """ Set entity_scope value.
+
+            Notes:
+                Specify if scope of entity is Data center or Enterprise level
+
+                
+                This attribute is named `entityScope` in VSD API.
+                
+        """
+        self._entity_scope = value
+
+    
     @property
     def mode(self):
         """ Get mode value.
@@ -472,7 +798,7 @@ class NUUplinkConnection(NURESTObject):
         """ Get port_name value.
 
             Notes:
-                Physical port name this uplink belongs to
+                Physical port name this uplink belongs to.
 
                 
                 This attribute is named `portName` in VSD API.
@@ -485,7 +811,7 @@ class NUUplinkConnection(NURESTObject):
         """ Set port_name value.
 
             Notes:
-                Physical port name this uplink belongs to
+                Physical port name this uplink belongs to.
 
                 
                 This attribute is named `portName` in VSD API.
@@ -499,7 +825,7 @@ class NUUplinkConnection(NURESTObject):
         """ Get download_rate_limit value.
 
             Notes:
-                Download rate limit for this uplink in Mbits/sec.
+                Download rate limit for this uplink in Mb/s.
 
                 
                 This attribute is named `downloadRateLimit` in VSD API.
@@ -512,7 +838,7 @@ class NUUplinkConnection(NURESTObject):
         """ Set download_rate_limit value.
 
             Notes:
-                Download rate limit for this uplink in Mbits/sec.
+                Download rate limit for this uplink in Mb/s.
 
                 
                 This attribute is named `downloadRateLimit` in VSD API.
@@ -526,7 +852,7 @@ class NUUplinkConnection(NURESTObject):
         """ Get uplink_id value.
 
             Notes:
-                ID that unqiuely identifies the uplink. 
+                ID that unqiuely identifies the uplink.
 
                 
                 This attribute is named `uplinkID` in VSD API.
@@ -539,7 +865,7 @@ class NUUplinkConnection(NURESTObject):
         """ Set uplink_id value.
 
             Notes:
-                ID that unqiuely identifies the uplink. 
+                ID that unqiuely identifies the uplink.
 
                 
                 This attribute is named `uplinkID` in VSD API.
@@ -553,7 +879,7 @@ class NUUplinkConnection(NURESTObject):
         """ Get username value.
 
             Notes:
-                PPPoE username
+                PPPoE username if uplink mode is set to PPPoE.
 
                 
         """
@@ -564,7 +890,7 @@ class NUUplinkConnection(NURESTObject):
         """ Set username value.
 
             Notes:
-                PPPoE username
+                PPPoE username if uplink mode is set to PPPoE.
 
                 
         """
@@ -679,5 +1005,32 @@ class NUUplinkConnection(NURESTObject):
         self._auxiliary_link = value
 
     
+    @property
+    def external_id(self):
+        """ Get external_id value.
+
+            Notes:
+                External object ID. Used for integration with third party systems
+
+                
+                This attribute is named `externalID` in VSD API.
+                
+        """
+        return self._external_id
+
+    @external_id.setter
+    def external_id(self, value):
+        """ Set external_id value.
+
+            Notes:
+                External object ID. Used for integration with third party systems
+
+                
+                This attribute is named `externalID` in VSD API.
+                
+        """
+        self._external_id = value
+
+    
 
     
\ No newline at end of file
